aboutsummaryrefslogtreecommitdiffstats
path: root/wiretap
diff options
context:
space:
mode:
Diffstat (limited to 'wiretap')
-rw-r--r--wiretap/file_access.c6
-rw-r--r--wiretap/nettrace_3gpp_32_423.c2
2 files changed, 4 insertions, 4 deletions
diff --git a/wiretap/nettrace_3gpp_32_423.c b/wiretap/nettrace_3gpp_32_423.c
index 80b297f85b..8af96939de 100644
--- a/wiretap/nettrace_3gpp_32_423.c
+++ b/wiretap/nettrace_3gpp_32_423.c
@@ -1,6 +1,6 @@
/* nettrace_3gpp_32_423.c
*
- * Decoder for 3GPP 32.423 file format for the Wiretap library.
+ * Decoder for 3GPP TS 32.423 file format for the Wiretap library.
* The main purpose is to have Wireshark decode raw message content (<rawMsg> tag).
*
* This program is free software; you can redistribute it and/or
diff --git a/wiretap/file_access.c b/wiretap/file_access.c
index 6842092a91..765e5889a4 100644
--- a/wiretap/file_access.c
+++ b/wiretap/file_access.c
@@ -349,8 +349,8 @@ static struct open_info open_info_base[] = {
{ "Symbian OS btsnoop", OPEN_INFO_MAGIC, btsnoop_open, "log", NULL, NULL },
{ "EyeSDN USB S0/E1 ISDN trace format", OPEN_INFO_MAGIC, eyesdn_open, NULL, NULL, NULL },
{ "Transport-Neutral Encapsulation Format", OPEN_INFO_MAGIC, tnef_open, NULL, NULL, NULL },
- /* 3GPP Nettrace must come before MIME Files as it's XML based*/
- { "3GPP Nettrace 32 423 Format", OPEN_INFO_MAGIC, nettrace_3gpp_32_423_file_open, NULL, NULL, NULL },
+ /* 3GPP TS 32.423 Trace must come before MIME Files as it's XML based*/
+ { "3GPP TS 32.423 Trace format", OPEN_INFO_MAGIC, nettrace_3gpp_32_423_file_open, NULL, NULL, NULL },
{ "MIME Files Format", OPEN_INFO_MAGIC, mime_file_open, NULL, NULL, NULL },
{ "Novell LANalyzer", OPEN_INFO_HEURISTIC, lanalyzer_open, "tr1", NULL, NULL },
/*
@@ -1609,7 +1609,7 @@ static const struct file_type_subtype_info dump_open_table_base[] = {
nstrace_35_dump_can_write_encap, nstrace_dump_open, NULL },
/* WTAP_FILE_TYPE_SUBTYPE_NETTRACE_3GPP_32_423 */
- { "Nettrace 3GPP 32 423", "nettrace3gpp324423", NULL, NULL,
+ { "3GPP TS 32.423 Trace", "nettrace3gpp324423", NULL, NULL,
FALSE, FALSE, 0,
NULL, NULL, NULL },
};